==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Engines/ffvideo/translations/ffvideo_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Engadido de video FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>Acerca do engadido FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Engadido de video FFmpeg-based para Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Compilado usando:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taxa de bits</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Taxa de bits de audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Taxa da mostra de Audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Canles de audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Tamaño do vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Taxa de bits de vídeo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Vídeo FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espacio</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Deter</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Engines/ffvideo/translations/ffvideo_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Engadido de video FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>Acerca do engadido FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Engadido de video FFmpeg-based para Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Compilado usando:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taxa de bits</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Taxa de bits de audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Taxa da mostra de Audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Canles de audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Tamaño do video</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Taxa de bits de vídeo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Vídeo FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espacio</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Deter</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>
